atom.params: Reading the atom parameters

View source: R/atom.params.R

atom.paramsR Documentation

Reading the atom parameters

Description

Returns a data frame with atom parameters read from a SQLite file.

Usage

atom.params(db.file)

Arguments

db.file

The SQLite file created after executing the empi.execute() function.

Value

Data frame with all the atom parameters saved in a given SQLite file. The file can be generated using the empi.execute() function.

Examples

# The file contains data with 18 channels.
file <- system.file("extdata", "EEG.db", package = "MatchingPursuit")
out <- atom.params(file)
out[which(out$channel_id == 1), ]
out[which(out$channel_id == 18), ]

# This file contains data with only 1 channel.
file <- system.file("extdata", "sample1.db", package = "MatchingPursuit")
out <- atom.params(file)
out


MatchingPursuit documentation built on April 9, 2026, 9:08 a.m.