empi.check: Checks if EMPI external software is installed

View source: R/empi.check.R

empi.checkR Documentation

Checks if EMPI external software is installed

Description

The EMPI program is installed using the empi.install() function and is stored in the cache directory. This function checks whether the EMPI program is still there (the user has free access to the cache directory and can, for example, delete it at any time).

Usage

empi.check()

Value

If the EMPI program is found, its full path is returned. Otherwise, a message is displayed, prompting the user to install it using the empi.install() function.

Examples

empi.check()


MatchingPursuit documentation built on April 9, 2026, 9:08 a.m.