empi.execute: Launches the empi program

View source: R/empi.execute.R

empi.executeR Documentation

Launches the empi program

Description

Runs the EMPI program for the given data (signal).

Usage

empi.execute(
  signal,
  empi.options = NULL,
  write.to.file = FALSE,
  path = NULL,
  file.name = NULL
)

Arguments

signal

List returned from read.csv.signals() function. The list stores the signal in a data frame along with its sampling frequency. The data should have logical column names (channel names).

empi.options

If NULL, the EMPI program runs with "-o local --gabor -i 50" parameters. Otherwise, user can specify any command-line options. See README.md file after downloading the EMPI program using empi.install() function.

write.to.file

If TRUE, a SQLite database file will be created and saved in the path directory or, (if path=NULL), in the cache directory. This file stores the results of signal decomposition using the MP algorithm.

path

Directory in which to save the SQLite database file. If it is NULL, the file will be saved in the cache directory.

file.name

The name of the file to generate if write.to.file=TRUE.

Details

The EMPI program (source and binary files for various operating systems) can be downloaded from https://github.com/develancer/empi. Details are presented in the journal paper: Różański, P. T. (2024). empi: GPU-Accelerated Matching Pursuit with Continuous Dictionaries.ACM Transactions on Mathematical Software, Volume 50, Issue 3, Article No. 17, pp. 1-17, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1145/3674832")}.

Value

Results of signal decomposition using the MP algorithm. If write.to.file=TRUE is specified, the results are also written to a SQLite file on disk in the path directory.

Examples

## Not run:
file <- system.file("extdata", "sample1.csv", package = "MatchingPursuit")
signal <- read.csv.signals(file)

empi.out <- empi.execute (
  signal = signal,
  empi.options = NULL,
  write.to.file = FALSE,
  path = NULL,
  file.name = NULL
)
## End(Not run)


MatchingPursuit documentation built on April 9, 2026, 9:08 a.m.