read.edf.params: Reads a selected EDF or EDF+ file and returns signal...

View source: R/read.edf.params.R

read.edf.paramsR Documentation

Reads a selected EDF or EDF+ file and returns signal parameters

Description

Reads a selected EDF or EDF+ file and returns selected signals parameters (channel names, frequency of each channel, number of samples in each channel and the length of each channel in seconds). Additional information stored in EDF+ files (such as interrupted recordings, time-stamped annotations) is not used in the package and is therefore not read.

Usage

read.edf.params(file)

Arguments

file

The path to the EDF / EDF+ file to be read.

Value

A data frame is returned containing the most basic parameters of the EDF / EDF+ file.

Examples

file <- system.file("extdata", "EEG.edf", package = "MatchingPursuit")
read.edf.params(file)


MatchingPursuit documentation built on April 9, 2026, 9:08 a.m.