| atom.params | R Documentation |
Returns a data frame with atom parameters read from a SQLite file.
atom.params(db.file)
db.file |
The SQLite file created after executing the |
Data frame with all the atom parameters saved in a given SQLite file.
The file can be generated using the empi.execute() function.
# The file contains data with 18 channels.
file <- system.file("extdata", "EEG.db", package = "MatchingPursuit")
out <- atom.params(file)
out[which(out$channel_id == 1), ]
out[which(out$channel_id == 18), ]
# This file contains data with only 1 channel.
file <- system.file("extdata", "sample1.db", package = "MatchingPursuit")
out <- atom.params(file)
out
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.