| empi.check | R Documentation |
The EMPI program is installed using the empi.install() function and is stored in the
cache directory. This function checks whether the EMPI program is still there (the user has
free access to the cache directory and can, for example, delete it at any time).
empi.check()
If the EMPI program is found, its full path is returned. Otherwise, a message is displayed,
prompting the user to install it using the empi.install() function.
empi.check()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.