| empi.execute | R Documentation |
Runs the EMPI program for the given data (signal).
empi.execute(
signal,
empi.options = NULL,
write.to.file = FALSE,
path = NULL,
file.name = NULL
)
signal |
List returned from |
empi.options |
If |
write.to.file |
If |
path |
Directory in which to save the SQLite database file.
If it is |
file.name |
The name of the file to generate if |
The EMPI program (source and binary files for various operating systems) can be downloaded from https://github.com/develancer/empi. Details are presented in the journal paper: Różański, P. T. (2024). empi: GPU-Accelerated Matching Pursuit with Continuous Dictionaries.ACM Transactions on Mathematical Software, Volume 50, Issue 3, Article No. 17, pp. 1-17, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1145/3674832")}.
Results of signal decomposition using the MP algorithm. If write.to.file=TRUE
is specified, the results are also written to a SQLite file on disk in the path
directory.
## Not run:
file <- system.file("extdata", "sample1.csv", package = "MatchingPursuit")
signal <- read.csv.signals(file)
empi.out <- empi.execute (
signal = signal,
empi.options = NULL,
write.to.file = FALSE,
path = NULL,
file.name = NULL
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.