| gabor.fun | R Documentation |
Gabor function is a sinusoidal wave localized by a Gaussian envelope. In signal processing it is widely used as a basic building block for representing signals that are localized in both time and frequency. Matching Pursuit algorithm uses a redundant dictionary of the so called Gabor atoms. Gabor atoms are ideal for Matching Pursuit because they: 1) provide optimal time–frequency localization, 2) represent oscillatory signals well, 3) enable adaptive time-frequency decomposition.
gabor.fun(
number.of.samples,
sampling.frequency,
mean,
phase,
sigma,
frequency,
normalization = TRUE
)
number.of.samples |
How many samples should the generated atom consist of? |
sampling.frequency |
Sampling frequency. |
mean |
Time position. |
phase |
Phase. |
sigma |
Scale / width of the Gaussian window. |
frequency |
Frequency of the sinusoid. |
normalization |
If |
List of 4 vectors with cosine, gauss, gabor and time waveforms of size number.of.samples.
number.of.samples <- 512
sampling.frequency <- 256.0
mean <- 1
phase <- pi
sigma <- 0.5
frequency <- 5.0
normalization = TRUE
out <- gabor.fun(
number.of.samples,
sampling.frequency,
mean,
phase,
sigma,
frequency,
normalization
)
# If normalization = TRUE, norm of atom = 1, we can check it
crossprod(out$gabor)
plot(out$t, out$gabor, type = "l", xlab = "t", ylab = "gabor", panel.first = grid())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.