View source: R/read.edf.params.R
| read.edf.params | R Documentation |
Reads a selected EDF or EDF+ file and returns selected signals parameters (channel names, frequency of each channel, number of samples in each channel and the length of each channel in seconds). Additional information stored in EDF+ files (such as interrupted recordings, time-stamped annotations) is not used in the package and is therefore not read.
read.edf.params(file)
file |
The path to the EDF / EDF+ file to be read. |
A data frame is returned containing the most basic parameters of the EDF / EDF+ file.
file <- system.file("extdata", "EEG.edf", package = "MatchingPursuit")
read.edf.params(file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.